%% Classify the 10,246 households into different dwelling types.
%----Author: Guru Raghav Raman----
%Run after executing the script "Load_data.m".

%To classify, we use the households' consumptions in the period of Nov 2019,
%Dec 2019, and Jan 2020.

%Classification categories:
%1: 1-Room / 2-Room HDB
%2: 3-Room HDB
%3: 4-Room HDB
%4: 5-Room and Executive HDB
%5: Private apartment and condominium
%6: Landed property

%% Calculate the average demand of a house.
%For each consumer, find the total energy consumption per day.
energy_consumption=sum(demand_data,1);

%Calculate the average consumption per consumer in Nov and Dec 2019.
avg_energy_consumption_nov2019=30*mean(energy_consumption(:,1:30,:),2); %There are 30 days in Nov.
avg_energy_consumption_dec2019=31*mean(energy_consumption(:,31:61,:),2); %There are 31 days in Dec.
avg_energy_consumption_jan2020=31*mean(energy_consumption(:,62:92,:),2); %There are 31 days in Jan.

%% Load average consumption data from EMA (Average Monthly Household Electricity Consumption by Dwelling Type).
%Based on 2019/2020 data
nov_avg_reported=[162.0 266.1 361.8 439.9 537.1 1191.8]; %NOV 2019
dec_avg_reported=[151.5 247.8 334.5 406.4 490.6 1089.8]; %DEC 2019
jan_avg_reported=[146.4 239.6 324.5 388.7 459.5 1072.4]; %JAN 2020

%% Classify thrice based on the consumption in the three months.
class_1=zeros(10246,1); %Initialization
class_2=zeros(10246,1); %Initialization
class_3=zeros(10246,1); %Initialization

for consumer=1:10246
    val1=avg_energy_consumption_nov2019(1,1,consumer);
    val2=nov_avg_reported;
    [~,class_1(consumer)]=min(abs(val1-val2));
end

for consumer=1:10246
    val1=avg_energy_consumption_dec2019(1,1,consumer);
    val2=dec_avg_reported;
    [~,class_2(consumer)]=min(abs(val1-val2));
end

for consumer=1:10246
    val1=avg_energy_consumption_jan2020(1,1,consumer);
    val2=jan_avg_reported;
    [~,class_3(consumer)]=min(abs(val1-val2));
end

%% Find the final classification. This is done by choosing the category that appears at least 2 of 3 times.
class_final=zeros(10246,1); %Initialization

for consumer=1:10246
    if (class_1(consumer)==class_2(consumer)) && (class_2(consumer)==class_3(consumer)) %If all classifications match, no problem!
        class_final(consumer)=class_1(consumer);
    elseif class_1(consumer)==class_2(consumer) %If at least two match, assign it to that class.
        class_final(consumer)=class_1(consumer);    
    elseif class_2(consumer)==class_3(consumer)
        class_final(consumer)=class_2(consumer);
    elseif class_1(consumer)==class_3(consumer)
        class_final(consumer)=class_1(consumer);
    else %If none of the three classifications match, simply decide based on Nov 2019 data.
        class_final(consumer)=class_1(consumer);    
    end
end

save('class_final','class_final');

%% Plot pie chart of final classification results.
figure(9)
C = categorical(class_final,1:6,{'1-Room / 2-Room HDB','3-Room HDB','4-Room HDB','5-Room and Executive HDB','Private apartment and condominium','Landed property'});
ax=gca();
pie(ax,C);
legend({'1-Room / 2-Room HDB','3-Room HDB','4-Room HDB','5-Room and Executive HDB','Private apartment and condominium','Landed property'});
ax.Colormap=[140,81,10;191,129,45;223,194,125;128,205,193;53,151,143;1,102,94]/255;